@@ -7,27 +7,8 @@
 # Authors:
 # - Muhammad Aditya Hilmy, <mhilmy@hey.com>, 2020
 
-import json
-from pathlib import Path
 from .handlers import setup_handlers
 
-HERE = Path(__file__).parent.resolve()
-
-with (HERE / "labextension" / "package.json").open() as fid:
-    data = json.load(fid)
-
-def _jupyter_labextension_paths():
-    return [{
-        "src": "labextension",
-        "dest": data["name"]
-    }]
-
-
-def _jupyter_server_extension_paths():  # pragma: no cover
-    return [{
-        "module": "rucio_jupyterlab.server"
-    }]
-
 
 def load_jupyter_server_extension(lab_app):  # pragma: no cover
     """Registers the API handler to receive HTTP requests from the frontend extension.
